@@ -17,6 +17,7 @@
  *       Jigish Gohil <cyberorg@opensuse.org>
  *       Wolfgang Schweer <schweer@cityweb.de>
  *       Toshio Kuratomi
+ * 2012, Alkis Georgopoulos <alkisg@gmail.com>
 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -194,17 +195,10 @@ destroy(GtkWidget * widget, gpointer data)
 }
 
 static void
-halt(GtkWidget * widget, gpointer data)
+spawn_command(GtkWidget * widget, const gchar *command)
 {
     GError **error = NULL;
-    g_spawn_command_line_async("/sbin/poweroff", error);
-}
-
-static void
-reboot(GtkWidget * widget, gpointer data)
-{
-    GError **error = NULL;
-    g_spawn_command_line_async("/sbin/reboot", error);
+    g_spawn_command_line_async(command, error);
 }
 
 gboolean
@@ -504,55 +498,83 @@ menu_append_pref(gpointer akey, gpointer avalue, gpointer adata) {
 static void
 popup_menu(GtkWidget * widget, GtkWindow * window)
 {
-    GtkWidget *menu, *lang_item, *sess_item, *host_item, *quit_item,
-        *reboot_item;
-    GtkWidget *sep, *langico, *sessico, *hostico, *rebootico, *haltico;
+    GtkWidget *menu, *lang_item, *sess_item, *host_item, *custom_item,
+        *quit_item, *reboot_item;
+    GtkWidget *sep, *langico, *sessico, *hostico, *customico, *rebootico,
+        *haltico;
+    gchar custom_env_var[20], *custom_mnemonic, *custom_command;
+    int i;
 
     menu = gtk_menu_new();
 
-    lang_item =
-        gtk_image_menu_item_new_with_mnemonic(_("Select _Language ..."));
-    langico = gtk_image_new_from_file(ldm_theme_file("language"));
-    gtk_image_menu_item_set_image((GtkImageMenuItem *) lang_item, langico);
+    if (getenv("LDM_FORCE_LANGUAGE") == NULL) {
+        lang_item =
+            gtk_image_menu_item_new_with_mnemonic(_("Select _Language ..."));
+        langico = gtk_image_new_from_file(ldm_theme_file("language"));
+        gtk_image_menu_item_set_image((GtkImageMenuItem *) lang_item, langico);
+        g_signal_connect_swapped(G_OBJECT(lang_item), "activate",
+                                 G_CALLBACK(langwin), window);
+        gtk_menu_shell_append(GTK_MENU_SHELL(menu), lang_item);
+    }
 
-    sess_item =
-        gtk_image_menu_item_new_with_mnemonic(_("Select _Session ..."));
-    sessico = gtk_image_new_from_file(ldm_theme_file("session"));
-    gtk_image_menu_item_set_image((GtkImageMenuItem *) sess_item, sessico);
+    if (getenv("LDM_FORCE_SESSION") == NULL) {
+        sess_item =
+            gtk_image_menu_item_new_with_mnemonic(_("Select _Session ..."));
+        sessico = gtk_image_new_from_file(ldm_theme_file("session"));
+        gtk_image_menu_item_set_image((GtkImageMenuItem *) sess_item, sessico);
+        g_signal_connect_swapped(G_OBJECT(sess_item), "activate",
+                                 G_CALLBACK(sesswin), window);
+        gtk_menu_shell_append(GTK_MENU_SHELL(menu), sess_item);
+    }
 
-    host_item =
-        gtk_image_menu_item_new_with_mnemonic(_("Select _Host ..."));
-    hostico = gtk_image_new_from_file(ldm_theme_file("host"));
-    gtk_image_menu_item_set_image((GtkImageMenuItem *) host_item, hostico);
+    if (ldminfo_size() > 1) {
+        host_item =
+            gtk_image_menu_item_new_with_mnemonic(_("Select _Host ..."));
+        hostico = gtk_image_new_from_file(ldm_theme_file("host"));
+        gtk_image_menu_item_set_image((GtkImageMenuItem *) host_item, hostico);
+        g_signal_connect_swapped(G_OBJECT(host_item), "activate",
+                                 G_CALLBACK(hostwin), window);
+        gtk_menu_shell_append(GTK_MENU_SHELL(menu), host_item);
+    }
+
+    for (i=0; i<=9; i++) {
+        g_sprintf(custom_env_var, "LDM_MENU_ITEM_%d", i);
+        custom_mnemonic=getenv(custom_env_var);
+        if (custom_mnemonic == NULL)
+            continue;
+        custom_item =
+            gtk_image_menu_item_new_with_mnemonic(custom_mnemonic);
+        g_sprintf(custom_env_var, "LDM_MENU_COMMAND_%d", i);
+        custom_command=getenv(custom_env_var);
+        if (custom_command == NULL) {
+            gtk_widget_destroy(custom_item);
+            continue;
+        }
+        customico = gtk_image_new_from_file(ldm_theme_file("backend"));
+        gtk_image_menu_item_set_image((GtkImageMenuItem *) custom_item,
+            customico);
+        g_signal_connect(G_OBJECT(custom_item), "activate",
+                         G_CALLBACK(spawn_command), g_strdup(custom_command));
+        gtk_menu_shell_append(GTK_MENU_SHELL(menu), custom_item);
+    }
+    greeter_pref_foreach(menu_append_pref, menu);
 
     sep = gtk_separator_menu_item_new();
+    gtk_menu_shell_append(GTK_MENU_SHELL(menu), sep);
+
     reboot_item = gtk_image_menu_item_new_with_mnemonic(_("_Reboot"));
     rebootico = gtk_image_new_from_file(ldm_theme_file("reboot"));
     gtk_image_menu_item_set_image((GtkImageMenuItem *) reboot_item,
                                   rebootico);
+    gtk_menu_shell_append(GTK_MENU_SHELL(menu), reboot_item);
+    g_signal_connect(G_OBJECT(reboot_item), "activate",
+                     G_CALLBACK(spawn_command), "/sbin/reboot");
+
     quit_item = gtk_image_menu_item_new_with_mnemonic(_("Shut_down"));
     haltico = gtk_image_new_from_file(ldm_theme_file("shutdown"));
     gtk_image_menu_item_set_image((GtkImageMenuItem *) quit_item, haltico);
-
-    g_signal_connect_swapped(G_OBJECT(quit_item), "activate",
-                             G_CALLBACK(halt), NULL);
-    g_signal_connect_swapped(G_OBJECT(reboot_item), "activate",
-                             G_CALLBACK(reboot), NULL);
-    g_signal_connect_swapped(G_OBJECT(lang_item), "activate",
-                             G_CALLBACK(langwin), window);
-    g_signal_connect_swapped(G_OBJECT(sess_item), "activate",
-                             G_CALLBACK(sesswin), window);
-    g_signal_connect_swapped(G_OBJECT(host_item), "activate",
-                             G_CALLBACK(hostwin), window);
-
-    greeter_pref_foreach(menu_append_pref, menu);
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu), lang_item);
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu), sess_item);
-    if (ldminfo_size() > 1)
-        gtk_menu_shell_append(GTK_MENU_SHELL(menu), host_item);
-
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu), sep);
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu), reboot_item);
+    g_signal_connect(G_OBJECT(quit_item), "activate",
+                     G_CALLBACK(spawn_command), "/sbin/poweroff");
     gtk_menu_shell_append(GTK_MENU_SHELL(menu), quit_item);
 
     gtk_menu_popup(GTK_MENU(menu), NULL, NULL, NULL, NULL,
@@ -789,8 +811,8 @@ main(int argc, char *argv[])
         timeoutspacer1 = gtk_label_new("");
         timeoutspacer2 = gtk_label_new("");
         timeoutlabel = gtk_label_new("");
-        gtk_box_pack_start(GTK_BOX(vbox), timeoutbox, FALSE, FALSE, 0);
         timeoutbox = gtk_hbox_new(FALSE, 0);
+        gtk_box_pack_start(GTK_BOX(vbox), timeoutbox, FALSE, FALSE, 0);
         gtk_box_pack_start(GTK_BOX(timeoutbox), timeoutspacer1, TRUE, FALSE, 0);
         gtk_box_pack_start(GTK_BOX(timeoutbox), timeoutlabel, FALSE, FALSE, 0);
         gtk_box_pack_start(GTK_BOX(timeoutbox), timeoutspacer2, TRUE, FALSE, 0);
