@@ -1,5 +1,8 @@
-#include "ldm-getenv-bool.h"
-#include "ldminfo.h"
+#ifndef LDM_H
+#define LDM_H
+
+#define _(text) gettext(text)
+#define DEFAULT_AUTH_PLUGIN "ssh"
 
 struct ldm_info {
     gchar    *server;
@@ -15,6 +18,7 @@ struct ldm_info {
     gchar    *sshoptions;
     gchar    *sound_daemon;
     gchar    *greeter_prog;
+    gchar    *wm_prog;
     gchar    *control_socket;
     gchar    *ipaddr;
     gboolean allowguest;
@@ -32,30 +36,17 @@ struct ldm_info {
     GPid     nomadpid;
     GPid     xsessionpid;
     GPid     greeterpid;
+    GPid     wmpid;
 };
 
-/* forward decls */
-
-void die(char *msg);
-pid_t ldm_spawn (gchar *command, gint *rfd, gint *wfd, void (*setup)());
-void ldm_wait(pid_t pid);
-int get_userid();
-int get_passwd();
-int get_language();
-int get_host();
-int get_session();
-void *eater(void);
-void ssh_session(void);
-void ssh_endsession(void);
-void close_greeter(void);
-void get_ipaddr(void);
-void loginfo(const char *format, ...);
-void logerr(const char *format, ...);
-int set_message(gchar *message);
+/* ldm.c specific */
+void get_ldm_env(void);
+void load_guestinfo(void);
 
+/* extern variables  */
 extern volatile sig_atomic_t unexpected_child;
 extern volatile sig_atomic_t child_exited;
+/* FIXME No more ldm_info extern */
 extern struct ldm_info ldm;
 
-#define SENTINEL "LTSPROCKS"
-#define MAXEXP 4096
+#endif
