@@ -3,7 +3,9 @@
 
 #define MAXBUFSIZE 16384
 
-/* 
+#include <glib.h>
+
+/*
  * state enum
  */
 
@@ -30,13 +32,11 @@ typedef struct {
  * ldminfo.c
  */
 
-/* 
+/*
  * Init the hash table : key=char hostnames, values=struct *ldminfo
  * ldm_server is the LDM_SERVER variable, a list of hostnames separated by space
  */
-
-void ldminfo_init(GHashTable ** lsminfo_hash, GList ** host_list,
-                  const char *ldm_server);
+void ldminfo_init(GList ** host_list, const char *ldm_server);
 
 /* Do the query for one host and fill ldminfo struct */
 void _ldminfo_query_one(const char *hostname, ldminfo * ldm_host_info);
@@ -44,4 +44,11 @@ void _ldminfo_query_one(const char *hostname, ldminfo * ldm_host_info);
 /* split string by line and then construct the ldm_host_info */
 void _ldminfo_parse_string(const char *s, ldminfo * ldm_host_info);
 
+int ldm_getenv_bool(const char *name);
+
+ldminfo *ldminfo_lookup(gconstpointer key);
+
+int ldminfo_size();
+
+void ldminfo_free();
 #endif
