@@ -118,8 +118,8 @@ void __attribute__ ((visibility("default"))) get_Xsession(gchar **xsession, gcon
  */
 void __attribute__ ((visibility("default"))) set_session_env(gchar *xsession, gchar *session) {
     if (g_strcmp0(session,"default") != 0 || getenv("LDM_SESSION") == NULL) {
-        log_entry("ldm",7,"Export LDM_SESSION to environment: \"%s\"", session);
-        setenv("LDM_SESSION", session, 1);
+        log_entry("ldm",7,"Export LDM_SELECTED_SESSION to environment: \"%s\"", session);
+        setenv("LDM_SELECTED_SESSION", session, 1);
     }
     else {
         log_entry("ldm",7,"Using existing LDM_SESSION from environment: \"%s\"", getenv("LDM_SESSION"));
