@@ -385,6 +385,7 @@ void ssh_chat(gint fd) {
         } else if (seen < 0) {
             set_message(_("No response from server, restarting..."));
             sleep(5);
+            close_greeter();
             die("ssh","no response, restarting");
         }
     }
@@ -403,7 +404,6 @@ void ssh_tty_init(void) {
  */
 void ssh_session(void) {
     gchar *command;
-    gchar *ssh_key_command;
     gchar *port = NULL;
     pthread_t pt;
 
@@ -413,15 +413,8 @@ void ssh_session(void) {
 
     openpty(&(sshinfo->sshfd), &(sshinfo->sshslavefd), NULL, NULL, NULL);
 
-    ssh_key_command = g_strjoin(" ", "/usr/share/ldm/ssh-hostchecker",
-            sshinfo->server,
-            "/var/run/ldm/ssh_known_hosts", NULL);
-
-    ldm_wait(ldm_spawn(ssh_key_command, NULL, NULL, NULL));
-
     command = g_strjoin(" ", "ssh", "-Y", "-t", "-M",
             "-S", sshinfo->ctl_socket,
-            "-o", "GlobalKnownHostsFile=/var/run/ldm/ssh_known_hosts",
             "-o", "NumberOfPasswordPrompts=1",
             "-l", sshinfo->username,
             port ? port : "",
